@@ -21,6 +21,11 @@ import aws_cdk.aws_sns_subscriptions
 import aws_cdk.aws_sqs
 import aws_cdk.core
 import constructs
-__all__ = []
+
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-lambda-event-sources", "1.33.0", __name__[0:-6], "aws-lambda-event-sources@1.33.0.jsii.tgz")
+
+__all__ = [
+    "__jsii_assembly__",
+]
 
 publication.publish()
